=== modified file 'src/unity-action.cpp'
--- src/unity-action.cpp	2013-07-12 12:50:29 +0000
+++ src/unity-action.cpp	2013-07-12 12:56:59 +0000
@@ -391,11 +391,26 @@
     emit parameterTypeChanged(value);
 }
 
+/*!
+ * Checks the value agains parameterType and triggers the action.
+ *
+ * if paramType is Action::None the action can be triggered by simly calling:
+ * \code
+ *     action->trigger();
+ * \endcode
+ *
+ * \note beware of the automatic conversion QVariant does. See the
+ *       QVariant documentation for details.
+ */
 void
 Action::trigger(QVariant value)
 {
     QMetaType::Type targetType = QMetaType::UnknownType;
 
+    if (!d->enabled) {
+        return;
+    }
+
     switch (d->parameterType) {
     case None: {
         break;

=== modified file 'test/cpp/tst_action.cpp'
--- test/cpp/tst_action.cpp	2013-06-27 21:16:51 +0000
+++ test/cpp/tst_action.cpp	2013-07-12 12:56:59 +0000
@@ -132,6 +132,15 @@
     spy.clear();
     action.setEnabled(false);
     QCOMPARE(spy.count(), 0);
+
+    action.setEnabled(true);
+    QSignalSpy trigger_spy(&action, SIGNAL(triggered(QVariant)));
+    action.trigger();
+    QCOMPARE(trigger_spy.count(), 1);
+    trigger_spy.clear();
+    action.setEnabled(false);
+    action.trigger();
+    QCOMPARE(trigger_spy.count(), 0);
 }
 
 void

